﻿--[ Utilities ]--

-- Returns true if the player is in a raid group
function VisualHeal:InRaid()
    return (GetNumRaidMembers() > 0);
end

-- Returns true if the player is in a party or a raid
function VisualHeal:InParty()
    return (GetNumPartyMembers() > 0);
end

-- Returns true if health information is available for the unit
function VisualHeal:UnitHasHealthInfo(unit)
    if (not unit) then 
        return false; 
    end
    if (UnitIsUnit('player', unit) or UnitIsUnit('pet', unit)) then 
        return true;
    end
    if (self:InRaid()) then
        -- In raid
        if (UnitPlayerOrPetInRaid(unit)) then 
            return true;
        end
    else
        -- Not in raid
        if (UnitPlayerOrPetInParty(unit)) then 
            return true;
        end
    end
    return false;
end

-- Determine if player is in a battleground
function VisualHeal:InBattleground()
    local id;
    for i=1,MAX_BATTLEFIELD_QUEUES do
        _, _, id = GetBattlefieldStatus(i);
        if id ~= 0 then return true end
    end
    return false;
end

function VisualHeal:EstimateUnitHealth(unit)
    local _, class = UnitClass(unit);
    class = class or "Unknown";
    local maxHealthTab = {
    warrior=4100,
    paladin=4000,
    shaman=3500,
    rogue=3100,
    hunter=3100,
    druid=3100,
    warlock=2300,
    mage=2200,
    priest=2100};
    return ((UnitHealth(unit) or 0) * (maxHealthTab[string.lower(class)] or 4000) * (UnitLevel(unit) or 60) / 3600);
end

-- 0 = equal
-- 1 = v1 most recent
-- 2 = v2 most recent
function VisualHeal:CompareVersions(v1, v2)
    local _, _, v1M, v1m = string.find(v1, "(%d+)\.(%d+)");
    local _, _, v2M, v2m = string.find(v2, "(%d+)\.(%d+)");

    if (v1M >= v2M) then
        if (v1M > v2M) then
            return 1;
        else
            -- v1M == v2M
            if (v1m >= v2m) then
                if (v1m > v2m) then
                    return 1;
                else
                    -- v1m == v2m
                    return 0;
                end
            else
                -- v1m < v2m
                return 2;
            end
        end
    else
        -- v1M < v2M
        return 2;
    end
end
